@@ -145,8 +145,8 @@ typedef struct PasswordDigest {
 	#define GlobalHistoryCount(A)			(A).historyCount
 	#define SetGlobalHistoryCount(A, B)		(A).historyCount = (B)
 #else
-	#define GlobalHistoryCount(A)			((A).hcPart1 | ((A).hcPart2 << 3))
-	#define SetGlobalHistoryCount(A, B)		{(A).hcPart1 = ((B) & 0x07); (A).hcPart2 = (((B) & 0x08) != 0);}
+	#define GlobalHistoryCount(A)			((A).hcLowBits | ((A).hcHighBit << 3))
+	#define SetGlobalHistoryCount(A, B)		{(A).hcLowBits = ((B) & 0x07); (A).hcHighBit = (((B) & 0x08) != 0);}
 #endif
 
 typedef struct PWGlobalAccessFeatures {
@@ -173,21 +173,20 @@ typedef struct PWGlobalAccessFeatures {
 #else
 	// unfortunately, <historyCount> crosses a byte boundary so there needs to be some post-processing
 	// for this struct.
-	unsigned int hcPart1:3;
-	unsigned int requiresMixedCase:1;		// TRUE == password must have one char in [A-Z], and one char in [a-z]
-	unsigned int newPasswordRequired:1;		// TRUE == new users must change their passwords on first login
-	unsigned int noModifyPasswordforSelf:1;	// TRUE == users cannot change their own passwords.
-	unsigned int requiresSymbol:1;
+	unsigned int hcHighBit:1;
+    unsigned int passwordCannotBeName:1;
+    unsigned int passwordIsHash:1;
+    unsigned int requiresNumeric:1;			// TRUE == password must have one char in [0-9]
+    unsigned int requiresAlpha:1;			// TRUE == password must have one char in [A-Z], [a-z]
+    unsigned int usingHardExpirationDate:1; // TRUE == look at hardExpirationDateGMT
+    unsigned int usingExpirationDate:1;		// TRUE == look at expirationDateGMT
+    unsigned int usingHistory:1;			// TRUE == users have password history files
 	unsigned int unused:1;
-	
-	unsigned int usingHistory:1;			// TRUE == users have password history files
-	unsigned int usingExpirationDate:1;		// TRUE == look at expirationDateGMT
-	unsigned int usingHardExpirationDate:1; // TRUE == look at hardExpirationDateGMT
-	unsigned int requiresAlpha:1;			// TRUE == password must have one char in [A-Z], [a-z]
-	unsigned int requiresNumeric:1;			// TRUE == password must have one char in [0-9]
-	unsigned int passwordIsHash:1;
-	unsigned int passwordCannotBeName:1;
-	unsigned int hcPart2:1;
+	unsigned int requiresSymbol:1;
+	unsigned int noModifyPasswordforSelf:1;	// TRUE == users cannot change their own passwords.
+	unsigned int newPasswordRequired:1;		// TRUE == new users must change their passwords on first login
+	unsigned int requiresMixedCase:1;		// TRUE == password must have one char in [A-Z], and one char in [a-z]
+	unsigned int hcLowBits:3;
 #endif
 
     BSDTimeStructCopy expirationDateGMT;	// if exceeded, user is required to change the password at next login
@@ -226,19 +225,19 @@ typedef struct PWAccessFeatures {
 	unsigned int historyCount:4;
 	int isSessionKeyAgent:1;				// the user can retrieve (MPPE) session keys
 #else
-    int requiresNumeric:1;					// TRUE == password must have one char in [0-9]
-	int passwordIsHash:1;
-	int passwordCannotBeName:1;
-	unsigned int historyCount:4;
-	int isSessionKeyAgent:1;				// the user can retrieve (MPPE) session keys
-    int isDisabled:1;						// TRUE == cannot log in
-    int isAdminUser:1;						// TRUE == can modify other slots in the db
-    int newPasswordRequired:1;				// TRUE == user is required to change the password at next login
-    int usingHistory:1;						// TRUE == user has a password history file
-    int canModifyPasswordforSelf:1;			// TRUE == user can modify their own password
-    int usingExpirationDate:1;				// TRUE == look at expirationDateGMT
-    int usingHardExpirationDate:1;			// TRUE == look at hardExpirationDateGMT
     int requiresAlpha:1;					// TRUE == password must have one char in [A-Z], [a-z]
+    int usingHardExpirationDate:1;			// TRUE == look at hardExpirationDateGMT
+    int usingExpirationDate:1;				// TRUE == look at expirationDateGMT
+    int canModifyPasswordforSelf:1;			// TRUE == user can modify their own password
+    int usingHistory:1;						// TRUE == user has a password history file
+    int newPasswordRequired:1;				// TRUE == user is required to change the password at next login
+    int isAdminUser:1;						// TRUE == can modify other slots in the db
+    int isDisabled:1;						// TRUE == cannot log in
+	int isSessionKeyAgent:1;				// the user can retrieve (MPPE) session keys
+	unsigned int historyCount:4;
+	int passwordCannotBeName:1;
+	int passwordIsHash:1;
+    int requiresNumeric:1;					// TRUE == password must have one char in [0-9]
 #endif
     
     BSDTimeStructCopy expirationDateGMT;	// if exceeded, user is required to change the password at next login
@@ -266,14 +265,16 @@ typedef struct PWMoreAccessFeatures {
 	unsigned int doNotReplicate:1;				// the password information does not get replicated
 	unsigned int doNotMerge:1; 					// used for restoring from backup
 	unsigned int requiresMixedCase:1;			// TRUE == password must have one char in [A-Z], and one char in [a-z]
-	int unused511:12; 							// reserved
+	unsigned int obfuscationCode:2;				// method of obfuscation for recoverable passwords
+	int unused511:10; 							// reserved
 #else
-	int unused511:8; 							// reserved
-	unsigned int recordIsDead:1;				// death certificate for deleted user
-	unsigned int doNotReplicate:1;				// the password information does not get replicated
-	unsigned int doNotMerge:1; 					// used for restoring from backup
+	unsigned int unused510:2;
+	unsigned int obfuscationCode:2;				// method of obfuscation for recoverable passwords
 	unsigned int requiresMixedCase:1;			// TRUE == password must have one char in [A-Z], and one char in [a-z]
-	unsigned int unused510:4;
+	unsigned int doNotMerge:1; 					// used for restoring from backup
+	unsigned int doNotReplicate:1;				// the password information does not get replicated
+	unsigned int recordIsDead:1;				// death certificate for deleted user
+	int unused511:8; 							// reserved
 #endif
 } PWMoreAccessFeatures;
 
@@ -319,7 +320,7 @@ typedef struct PWFileEntry {
     
     PWAccessFeatures access;					// password policy data determined by marketing
     
-    // WARNING: The following field is the key to the kindom. It should never, ever, ever,
+    // WARNING: The following field is the key to the kingdom. It should never, ever, ever,
     // ever, be sent across the network or dumped to any log file!!!!
     
     char passwordStr[512];						// the password
@@ -364,6 +365,7 @@ char * pwsf_ShadowHashArrayToData( CFArrayRef inHashTypeArray, long *outResultLe
 void pwsf_AppendUTF8StringToArray( const char *inUTF8Str, CFMutableArrayRef inArray );
 void pwsf_EndianAdjustTimeStruct( BSDTimeStructCopy *inOutTimeStruct, int native );
 void pwsf_EndianAdjustPWFileHeader( PWFileHeader *inOutHeader, int native );
+void pwsf_EndianAdjustPWFileEntry( PWFileEntry *inOutEntry, int native );
 
 // in CAuthFileBase.cpp
 int pwsf_TestDisabledStatus( PWAccessFeatures *inAccess, PWGlobalAccessFeatures *inGAccess, struct tm *inCreationDate, struct tm *inLastLoginTime, UInt16 *inOutFailedLoginAttempts );
